@@ -140,11 +140,11 @@ class _BaseFilter(_utilities.ConfigNode):
 
 @dataclasses.dataclass(frozen=True)
 class PythonFilter(_BaseFilter):
-    """Custom python filter
+    """Create a filter by referencing a python function
 
     Attributes:
-        - func -- Custom python filter (required)
-        - params -- Custom python filter (optional, default: None)
+        - func -- Provide a function whose python source will be used as the filter definition (required)
+        - params -- Optional params to feed to the captured python function (optional, default: None)
 
     """
 
@@ -152,14 +152,40 @@ class PythonFilter(_BaseFilter):
     func: typing.Callable[
         [
             typing.Optional[typing.Any],
-            typing.Optional[typing.Dict[str, typing.Union[str, int, float, bool]]],
+            typing.Optional[
+                typing.Dict[
+                    str,
+                    typing.Union[
+                        str,
+                        int,
+                        float,
+                        bool,
+                        typing.List[str],
+                        typing.List[int],
+                        typing.List[float],
+                        typing.List[bool],
+                    ],
+                ]
+            ],
         ],
         bool,
     ]
 
     # optional
     params: typing.Optional[
-        typing.Dict[str, typing.Union[str, int, float, bool]]
+        typing.Dict[
+            str,
+            typing.Union[
+                str,
+                int,
+                float,
+                bool,
+                typing.List[str],
+                typing.List[int],
+                typing.List[float],
+                typing.List[bool],
+            ],
+        ]
     ] = None
 
     # internal private methods
@@ -221,7 +247,7 @@ class JSONUnitTest(_BaseUnitTest):
 
 @dataclasses.dataclass(frozen=True)
 class Rule(_utilities.ConfigNode):
-    """Define a rule
+    """Define a Rule-type detection to execute against log data in your Panther instance
 
     Attributes:
         - filters -- Define event filters for the rule (required)
@@ -234,7 +260,6 @@ class Rule(_utilities.ConfigNode):
         - description -- Description for the rule (optional, default: "")
         - destinations -- Alert destinations for the rule (optional, default: None)
         - enabled -- Short description for the query (optional, default: True)
-        - group -- Number of matches received before an alert is triggered (optional, default: 1)
         - name -- Display name for the rule (optional, default: "")
         - reference -- Reference for the rule (optional, default: "")
         - reports -- Report mappings for the rule (optional, default: None)
@@ -280,9 +305,6 @@ class Rule(_utilities.ConfigNode):
     # optional
     enabled: bool = True
 
-    # optional
-    group: int = 1
-
     # optional
     name: typing.Optional[str] = ""
 
@@ -328,7 +350,6 @@ class Rule(_utilities.ConfigNode):
             "description",
             "destinations",
             "enabled",
-            "group",
             "name",
             "reference",
             "reports",
